import { ColumnState } from '@ag-grid-community/core';
/**
 * Represents a state persistence and its capabilities.
 * Provides methods to set and get columns from the storage.
 * @public
 */
export interface StatePersistence {
    /**
     * Returns the column state for the given key.
     * @public
     */
    getColumnState(persistColumnStateKey: string): Promise<ColumnState[]>;
    /**
     * Saves the column state for the given key.
     * @public
     */
    saveColumnState(persistColumnStateKey: string, columnState: ColumnState[]): Promise<void>;
    /**
     * Returns the filter model for the given key.
     * @public
     */
    getFilterModel(persistFilterModelKey: string): Promise<{
        [key: string]: any;
    }>;
    /**
     * Saves the filter model for the given key.
     * @public
     */
    saveFilterModel(persistFilterModelKey: string, filterModel: {
        [key: string]: any;
    }): Promise<void>;
}
/**
 * The DI token for the StatePersistence interface.
 * @internal
 */
export declare const StatePersistence: import("@microsoft/fast-foundation").InterfaceSymbol<StatePersistence>;
//# sourceMappingURL=state-persistence.d.ts.map